@@ -70,7 +70,7 @@ def repository_handler(repoent):
             return repohdlr
 
 
-def import_content(session, repo, commitevery=10):
+def import_content(session, commitevery=10):
     """synchronize content of known vcs repositories
 
     `repo` is the cubicweb repository (not a vcs repository)
@@ -82,7 +82,7 @@ def import_content(session, repo, commitevery=10):
         try:
             repohdlr = repository_handler(vcsrepo)
         except VCSException, ex:
-            repo.error(str(ex))
+            session.error(str(ex))
             continue
         import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10)
 
@@ -91,7 +91,10 @@ def import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10):
     """synchronize content of given vcs repository"""
     try:
         repohdlr.import_content(vcsrepo, commitevery)
+        # give other threads a chance to run: commit will release the pool, get
+        # it back afterwards
         session.commit()
+        session.set_pool()
     except:
         try:
             title = vcsrepo.dc_title()
