@@ -34,6 +34,16 @@ def rql_revision_content(repoeid, revnum, branch=None):
 
 _MARKER = object()
 
+def remove_authinfo(url):
+    try:
+        base, remaining = url.split('@')
+    except ValueError:
+        return url
+    try:
+        scheme, authinfo = base.split('://')
+    except ValueError:
+        return url
+    return u'%s://***@%s' % (scheme, remaining)
 
 class Repository(AnyEntity):
     """customized class for Repository entities"""
@@ -47,7 +57,7 @@ class Repository(AnyEntity):
         if self.title:
             return self.title
         if self.source_url:
-            return self.source_url
+            return remove_authinfo(self.source_url)
         if self.path: # None if user isn't authorized to see path attribute
             title = '%s:%s' % (self.type, self.path)
             if self.subpath:
@@ -61,6 +71,19 @@ class Repository(AnyEntity):
         super(Repository, self).clear_all_caches()
         clear_cache(self, 'branch_head')
 
+    def printable_value(self, attr, *args, **kwargs):
+        if attr == 'source_url':
+            if args:
+                value = args[0]
+            elif 'value' in kwargs:
+                value = kwargs['value']
+            else:
+                value = self.source_url
+            if value:
+                return remove_authinfo(value)
+            return u''
+        return super(Repository, self).printable_value(attr, *args, **kwargs)
+
     # navigation in versioned content #########################################
 
     def latest_known_revision(self):
