@@ -147,8 +147,6 @@ class ServerStartupHook(Hook):
                         repohdlr.exception(
                             'error while updating local cache of repository %s',
                             vcsrepo.eid)
-                    # give other threads a chance to run
-                    session.set_pool()
                     if repo.config['repository-import']:
                         bridge.import_vcsrepo_content(
                             session, repohdlr, vcsrepo,
