@@ -16,6 +16,7 @@ from mercurial.node import nullid, short as short_hex
 from cubicweb import Binary, QueryError
 
 from cubes.vcsfile import repo, bridge
+from cubes.vcsfile.entities import remove_authinfo
 
 _DELETED = object()
 
@@ -73,7 +74,7 @@ class HGRepository(repo.VCSRepository):
             hgcmd.clone(vcsfile_ui(self), str(url),
                         dest=self.path, stream='compressed', noupdate=True)
         else:
-            self.info('pulling from %s into %s', url, self.path)
+            self.info('pulling from %s into %s', remove_authinfo(url), self.path)
             vui = vcsfile_ui(self)
             hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url))
 
