@@ -5,7 +5,7 @@ from os.path import join, split, exists, abspath
 import tempfile
 
 from cubicweb import Binary, QueryError, ValidationError, Unauthorized
-
+from cubicweb import devtools # makes cubes importable
 from cubes.vcsfile import entities, bridge
 
 from utils import VCSFileTC
@@ -29,14 +29,14 @@ class _WriteTC(VCSFileTC):
         rmtree(str(self._repo_path))
 
     def _test_new_revision(self, entity, vf, rev, revision):
-        self.assertEquals(entity.content_for[0].eid, vf.eid)
-        self.assertEquals(entity.description, u'add hôp')
-        self.assertEquals(entity.author, 'syt')
-        self.assertEquals(entity.data.getvalue(), 'hop\nhop\nhop\n')
-        self.assertEquals(entity.data_encoding.lower(), self.repo_encoding)
-        self.assertEquals(entity.data_format, 'text/plain')
-        self.assertEquals(entity.rev.eid, rev.eid)
-        self.assertEquals(entity.rev.revision, revision)
+        self.assertEqual(entity.content_for[0].eid, vf.eid)
+        self.assertEqual(entity.description, u'add hôp')
+        self.assertEqual(entity.author, 'syt')
+        self.assertEqual(entity.data.getvalue(), 'hop\nhop\nhop\n')
+        self.assertEqual(entity.data_encoding.lower(), self.repo_encoding)
+        self.assertEqual(entity.data_format, 'text/plain')
+        self.assertEqual(entity.rev.eid, rev.eid)
+        self.assertEqual(entity.rev.revision, revision)
         self.assertTrue(entity.rev.parent_revision)
         self.assertTrue(entity.rev.reverse_at_revision)
 
@@ -55,10 +55,10 @@ class _WriteTC(VCSFileTC):
         self._test_new_revision(vc, vf, rev, 8 + self.repo_rev_offset)
         try:
             session = self.repo.internal_session()
-            bridge.import_content(session, self.repo)
+            bridge.import_content(session)
         finally:
             session.close()
-        self.assertEquals(len(self.execute('Any X WHERE X revision %(r)s', {'r': rev.revision})), 1)
+        self.assertEqual(len(self.execute('Any X WHERE X revision %(r)s', {'r': rev.revision})), 1)
 
     def test_new_revision_security(self):
         self.execute('DELETE CWPermission X')
@@ -88,7 +88,7 @@ class _WriteTC(VCSFileTC):
         rset = self.execute('Any X WHERE X eid %(x)s', {'x': vc.eid})
         self.failIf(rset)
         rset = self.execute('VersionContent X WHERE X content_for VF, VF eid %(vf)s', {'vf': vf.eid})
-        self.assertEquals(len(rset), 2)
+        self.assertEqual(len(rset), 2)
         # XXX check actually not in the repository
 
     def test_error_new_revision(self):
@@ -174,14 +174,14 @@ class _WriteTC(VCSFileTC):
         self.commit()
         entity = self.execute('Any X WHERE X eid %(x)s', {'x': eid}).get_entity(0, 0)
         vf = entity.content_for[0]
-        self.assertEquals(vf.from_repository[0].eid, self.repoeid)
-        self.assertEquals(vf.directory, 'dir1')
-        self.assertEquals(vf.name, 'tutu.png')
-        self.assertEquals(entity.description, 'new file')
-        self.assertEquals(entity.author, 'syt')
-        self.assertEquals(entity.data.getvalue(), 'zoubî')
-        self.assertEquals(entity.data_encoding, None)
-        self.assertEquals(entity.data_format, 'image/png')
+        self.assertEqual(vf.from_repository[0].eid, self.repoeid)
+        self.assertEqual(vf.directory, 'dir1')
+        self.assertEqual(vf.name, 'tutu.png')
+        self.assertEqual(entity.description, 'new file')
+        self.assertEqual(entity.author, 'syt')
+        self.assertEqual(entity.data.getvalue(), 'zoubî')
+        self.assertEqual(entity.data_encoding, None)
+        self.assertEqual(entity.data_format, 'image/png')
 
     def test_error_new_file(self):
         self.execute('INSERT VersionedFile X: X directory %(dir)s, X name %(name)s WHERE R eid %(repo)s',
@@ -211,18 +211,18 @@ class _WriteTC(VCSFileTC):
         self.commit()
         self.assertFalse(self.vcsrepo.is_directory_deleted('dir1'))
         entity1 = self.execute('Any X WHERE X eid %(x)s', {'x': eid1}).get_entity(0, 0)
-        self.assertEquals(entity1.content_for[0].eid, vf1[0][0])
-        self.assertEquals(entity1.description, 'add hop')
-        self.assertEquals(entity1.author, 'syt')
-        self.assertEquals(entity1.data.getvalue(), 'hop\nhop\nhop\n')
+        self.assertEqual(entity1.content_for[0].eid, vf1[0][0])
+        self.assertEqual(entity1.description, 'add hop')
+        self.assertEqual(entity1.author, 'syt')
+        self.assertEqual(entity1.data.getvalue(), 'hop\nhop\nhop\n')
         entity2 = self.execute('Any X WHERE X eid %(x)s', {'x': eid2}).get_entity(0, 0)
         vf2 = entity2.content_for[0]
-        self.assertEquals(vf2.from_repository[0].eid, self.repoeid)
-        self.assertEquals(vf2.directory, 'dir1')
-        self.assertEquals(vf2.name, 'tutu.txt')
-        self.assertEquals(entity2.description, 'add hop')
-        self.assertEquals(entity2.author, 'syt')
-        self.assertEquals(entity2.data.getvalue(), 'zoubî')
+        self.assertEqual(vf2.from_repository[0].eid, self.repoeid)
+        self.assertEqual(vf2.directory, 'dir1')
+        self.assertEqual(vf2.name, 'tutu.txt')
+        self.assertEqual(entity2.description, 'add hop')
+        self.assertEqual(entity2.author, 'syt')
+        self.assertEqual(entity2.data.getvalue(), 'zoubî')
         # deletion
         tmpdir = tempfile.mkdtemp()
         try:
@@ -241,9 +241,9 @@ class _WriteTC(VCSFileTC):
                            {'vf': vf1[0][0], 'r': reveid})[0][0]
         self.commit()
         entity1 = self.execute('Any X WHERE X eid %(x)s', {'x': eid1}).get_entity(0, 0)
-        self.assertEquals(entity1.content_for[0].eid, vf1[0][0])
-        self.assertEquals(entity1.description, 'kill')
-        self.assertEquals(entity1.author, 'auc')
+        self.assertEqual(entity1.content_for[0].eid, vf1[0][0])
+        self.assertEqual(entity1.description, 'kill')
+        self.assertEqual(entity1.author, 'auc')
         tmpdir = tempfile.mkdtemp()
         try:
             self.checkout(tmpdir)
@@ -254,10 +254,10 @@ class _WriteTC(VCSFileTC):
             rmtree(tmpdir)
         oddfile = self.execute('VersionedFile F WHERE F name "__hg_needs_a_file__"').get_entity(0,0)
         content = vf1.get_entity(0,0).reverse_content_for
-        self.assertEquals(len(content), 4)
+        self.assertEqual(len(content), 4)
         self.assertIsInstance(content[0], entities.DeletedVersionContent)
         content = oddfile.reverse_content_for
-        self.assertEquals(len(content), 2)
+        self.assertEqual(len(content), 2)
         self.assertIsInstance(content[0], entities.DeletedVersionContent)
         self.failUnless(self.vcsrepo.is_directory_deleted('dir1/ghostdir'))
 
@@ -291,23 +291,23 @@ class HGSourceWriteTC(_WriteTC):
                                               branch=u'1.2.3')
         self.commit()
         hgdir = self.copath
-        self.assertEquals(file(join(hgdir, 'toto.txt')).read(),
+        self.assertEqual(file(join(hgdir, 'toto.txt')).read(),
                           'hop\nhop\n\n')
         system('cd %s; hg up 1.2.3 >/dev/null 2>&1' % hgdir)
-        self.assertEquals(file(join(hgdir, 'toto.txt')).read(),
+        self.assertEqual(file(join(hgdir, 'toto.txt')).read(),
                           'branch 1.2.3 content')
         # create new changeset in the default branch
         vf, rev, vc = self._new_toto_revision(data='branch default content')
         self.commit()
         system('cd %s; hg up default >/dev/null 2>&1' % hgdir)
-        self.assertEquals(file(join(hgdir, 'toto.txt')).read(),
+        self.assertEqual(file(join(hgdir, 'toto.txt')).read(),
                           'branch default content')
         # create new changeset in the 1.2.3 branch
         vf, rev, vc = self._new_toto_revision(data='branch 1.2.3 new content',
                                               branch=u'1.2.3')
         self.commit()
         system('cd %s; hg up default >/dev/null 2>&1' % hgdir)
-        self.assertEquals(file(join(hgdir, 'toto.txt')).read(),
+        self.assertEqual(file(join(hgdir, 'toto.txt')).read(),
                           'branch default content')
         # delete file from both branches
         vf.vcs_rm(branch=u'default', author=u'titi')
@@ -320,39 +320,39 @@ class HGSourceWriteTC(_WriteTC):
         self.failIf(exists((join(hgdir, 'toto.txt'))))
         vf.clear_all_caches()
         ex = self.assertRaises(QueryError, vf.vcs_rm, branch=u'1.2.3', author=u'toto')
-        self.assertEquals(str(ex), 'toto.txt is already deleted from the vcs')
+        self.assertEqual(str(ex), 'toto.txt is already deleted from the vcs')
 
     def test_strip(self):
-        self.assertEquals(self.vcsrepo.latest_known_revision(), 6)
+        self.assertEqual(self.vcsrepo.latest_known_revision(), 6)
         vcrset = self.execute('Any X WHERE X from_revision R, R revision 6')
         system('cd %s; hg --config extensions.hgext.mq= strip 6 2>/dev/null' % self.copath)
         try:
             session = self.repo.internal_session()
-            bridge.import_content(session, self.repo)
+            bridge.import_content(session)
         finally:
             session.close()
         self.commit()
-        self.assertEquals(self.vcsrepo.latest_known_revision(), 5)
+        self.assertEqual(self.vcsrepo.latest_known_revision(), 5)
         for eid, in vcrset:
             self.failIf(self.execute('Any X WHERE X eid %(x)s', {'x': eid}))
 
     def test_branches_from_hg(self):
-        self.assertEquals(self.execute('Any COUNT(R) WHERE R is Revision').rows, [[7]])
+        self.assertEqual(self.execute('Any COUNT(R) WHERE R is Revision').rows, [[7]])
         hgdir = self.copath
         system('cd %s; hg up default >/dev/null 2>&1' % hgdir)
         system('cd %s; hg branch newbranch >/dev/null 2>&1' % hgdir)
         system('cd %s; hg tag newbranch -m "opening newbranch"' % hgdir)
         try:
             session = self.repo.internal_session()
-            bridge.import_content(session, self.repo)
+            bridge.import_content(session)
         finally:
             session.close()
         self.commit()
         hgtags = self.execute('VersionContent V WHERE V content_for VF,  '
                               'VF name ".hgtags"').get_entity(0,0)
-        self.assertEquals(hgtags.from_revision[0].branch, u'newbranch')
-        self.assertEquals(hgtags.from_revision[0].revision, 7)
-        self.assertEquals(self.execute('Any COUNT(R) WHERE R is Revision').rows, [[8]])
+        self.assertEqual(hgtags.from_revision[0].branch, u'newbranch')
+        self.assertEqual(hgtags.from_revision[0].revision, 7)
+        self.assertEqual(self.execute('Any COUNT(R) WHERE R is Revision').rows, [[8]])
 
 
 
